@@ -65,20 +65,20 @@ use Scalar::Util ();
 
 use vars qw{$VERSION @ISA @EXPORT_OK %EXPORT_TAGS};
 BEGIN {
-	$VERSION   = '0.24';
+	$VERSION   = '0.26';
 	@ISA       = 'Exporter';
 
 	@EXPORT_OK = qw{
-		_STRING     _IDENTIFIER _CLASS
-		_POSINT 
+		_STRING     _IDENTIFIER
+		_CLASS      _CLASSISA   _SUBCLASS  _DRIVER
+		_POSINT     _NONNEGINT
 		_SCALAR     _SCALAR0
-		_ARRAY      _ARRAY0    _ARRAYLIKE
-		_HASH       _HASH0     _HASHLIKE
-		_CODE       _CODELIKE  _CALLABLE
+		_ARRAY      _ARRAY0     _ARRAYLIKE
+		_HASH       _HASH0      _HASHLIKE
+		_CODE       _CODELIKE   _CALLABLE
 		_INVOCANT
-		_INSTANCE   _SET       _SET0
+		_INSTANCE   _SET        _SET0
 		_HANDLE
-		_DRIVER
 		};
 
 	%EXPORT_TAGS = (ALL => \@EXPORT_OK);
@@ -160,6 +160,54 @@ sub _CLASS ($) {
 
 =pod
 
+=head2 _CLASSISA $string, $class
+
+The C<_CLASSISA> function is intended to be imported into your
+package, and provides a convenient way to test to see if a value is
+a string that is a particularly class, or a subclass of it.
+
+This function checks that the format is valid and calls the -E<gt>isa
+method on the class name. It does not check that the class is actually
+loaded.
+
+It also assumes "normalised" form, and does
+not accept class names such as C<::Foo> or C<D'Oh>.
+
+Returns the string as a convenience if it is a valid class name, or
+C<undef> if not.
+
+=cut
+
+sub _CLASSISA ($$) {
+	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^[^\W\d]\w*(?:::\w+)*$/s and $_[0]->isa($_[1])) ? $_[0] : undef;
+}
+
+=pod
+
+=head2 _SUBCLASS $string, $class
+
+The C<_SUBCLASS> function is intended to be imported into your
+package, and provides a convenient way to test to see if a value is
+a string that is a subclass of a specified class.
+
+This function checks that the format is valid and calls the -E<gt>isa
+method on the class name. It does not check that the class is actually
+loaded.
+
+It also assumes "normalised" form, and does
+not accept class names such as C<::Foo> or C<D'Oh>.
+
+Returns the string as a convenience if it is a valid class name, or
+C<undef> if not.
+
+=cut
+
+sub _SUBCLASS ($$) {
+	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^[^\W\d]\w*(?:::\w+)*$/s and $_[0] ne $_[1] and $_[0]->isa($_[1])) ? $_[0] : undef;
+}
+
+=pod
+
 =head2 _POSINT $integer
 
 The C<_POSINT> function is intended to be imported into your
@@ -169,6 +217,9 @@ a positive integer (of any length).
 Returns the value as a convience, or C<undef> if the value is not a
 positive integer.
 
+The name itself is derived from the XML schema constraint of the same
+name.
+
 =cut
 
 sub _POSINT ($) {
@@ -177,6 +228,34 @@ sub _POSINT ($) {
 
 =pod
 
+=head2 _NONNEGINT $integer
+
+The C<_NONNEGINT> function is intended to be imported into your
+package, and provides a convenient way to test to see if a value is
+a non-negative integer (of any length). That is, a positive integer,
+or zero.
+
+Returns the value as a convience, or C<undef> if the value is not a
+non-negative integer.
+
+As with other tests that may return false values, care should be taken
+to test via "defined" in boolean validy contexts.
+
+  unless ( defined _NONNEGINT($value) ) {
+     die "Invalid value";
+  }
+
+The name itself is derived from the XML schema constraint of the same
+name.
+
+=cut
+
+sub _NONNEGINT ($) {
+	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^(?:0|[1-9]\d*)$/) ? $_[0] : undef;
+}
+
+=pod
+
 =head2 _SCALAR \$scalar
 
 The C<_SCALAR> function is intended to be imported into your package,
